@@ -861,9 +861,17 @@ protected:
 public:
     /**
      * Construct a semaphore with an initial count of threads to permit.
+     * @param count of threads to permit, or special case 0 group release.
      */
     Semaphore(unsigned count = 0);
 
+    /**
+     * Alternate onstructor with ability to preset available slots.
+     * @param count of threads to permit.
+     * @param avail instances not pre-locked.
+     */
+    Semaphore(unsigned count, unsigned avail);
+
     /**
      * Wait until the semphore usage count is less than the thread limit.
      * Increase used count for our thread when unblocked.
