@@ -1,4 +1,4 @@
-// Copyright (C) 2010 David Sugar, Tycho Softworks.
+// Copyright (C) 2010-2014 David Sugar, Tycho Softworks.
 //
 // This file is part of GNU uCommon C++.
 //
@@ -17,6 +17,8 @@
 
 #include "local.h"
 
+NAMESPACE_UCOMMON
+
 bool HMAC::has(const char *id)
 {
     return (EVP_get_digestbyname(id) != NULL);
@@ -33,7 +35,7 @@ void HMAC::set(const char *digest, const char *key, size_t len)
 
     hmactype = EVP_get_digestbyname(digest);
     if(hmactype && len) {
-        context = new HMAC_CTX;
+        context = new ::HMAC_CTX;
         HMAC_CTX_init((HMAC_CTX *)context);
         HMAC_Init((HMAC_CTX *)context, key, len, (const EVP_MD *)hmactype);
     }
@@ -89,3 +91,4 @@ buffer[count]);
     return buffer;
 }
 
+END_NAMESPACE
